package com.srs.teacher.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.teacher.domain.SysTeacherStudy;

/**
 * studyService接口
 *
 * @author srs
 * @date 2024-05-28
 */
public interface ISysTeacherStudyService extends IService<SysTeacherStudy> {
    /**
     * 查询study
     *
     * @param studyId study主键
     * @return study
     */
    public SysTeacherStudy selectSysTeacherStudyByStudyId(Long studyId);

    /**
     * 查询study列表
     *
     * @param sysTeacherStudy study
     * @return study集合
     */
    List<SysTeacherStudy> selectSysTeacherStudyList(SysTeacherStudy sysTeacherStudy);

    /**
     * 新增study
     *
     * @param sysTeacherStudy study
     * @return 结果
     */
    int insertSysTeacherStudy(SysTeacherStudy sysTeacherStudy);

    /**
     * 修改study
     *
     * @param sysTeacherStudy study
     * @return 结果
     */
    int updateSysTeacherStudy(SysTeacherStudy sysTeacherStudy);

    /**
     * 批量删除study
     *
     * @param studyIds 需要删除的study主键集合
     * @return 结果
     */
    int deleteSysTeacherStudyByStudyIds(Long[] studyIds);

    /**
     * 删除study信息
     *
     * @param studyId study主键
     * @return 结果
     */
    int deleteSysTeacherStudyByStudyId(Long studyId);
}
